<?php
namespace edu\wisc\services\cbs\common;

use edu\wisc\services\cbs\exception\UnsupportedCurrencyException;
use Money\Money;

/**
 * Provides conversion methods for {@link Money} instances.
 */
class MoneyConversion
{

    /**
     * Converts a {@link Money} instance into a float.
     *
     * @param Money $money  money to convert
     * @return float|null  float value of money, null if null was provided
     * @throws UnsupportedCurrencyException  if a currency other than USD is provided
     */
    public static function convertMoneyToFloat(Money $money = null)
    {
        $costFloat = null;
        if (null !== $money) {
            $currency = $money->getCurrency()->getName();
            if ($currency !== 'USD') {
                throw new UnsupportedCurrencyException("Unsupported currency: $currency");
            }
            $amount = $money->getAmount();
            $costFloat = (float) $amount / 100;
        }
        return $costFloat;
    }
}
