<?php

namespace edu\wisc\services\cbs\order\payment;

use edu\wisc\services\cbs\api\SoapService;
use edu\wisc\services\cbs\common\WssSoapHeaderBuilder;
use edu\wisc\services\cbs\order\payment\generated\DOIT_SOA_PAYMENT_V2_Service;
use edu\wisc\services\cbs\order\payment\generated\OutputParameters;

use Money\Money;

/**
 * A SOAP implementation of {@link OrderPaymentService}.
 */
class SoapOrderPaymentService implements OrderPaymentService, SoapService
{

    /** @var DOIT_SOA_PAYMENT_V2_Service */
    private $soapClient;

    /**
     * {@inheritdoc}
     */
    public function __construct($username, $password, $wsdlPath = null, \SoapClient $paymentSoapClient = null)
    {
        if ($paymentSoapClient !== null) {
            $this->soapClient = $paymentSoapClient;
            return;
        } else if ($wsdlPath !== null) {
            $this->soapClient = new DOIT_SOA_PAYMENT_V2_Service(
                [],
                $wsdlPath
            );
            $this->soapClient->__setSoapHeaders(WssSoapHeaderBuilder::buildUsernameToken($username, $password));
        } else {
            $this->soapClient = new DOIT_SOA_PAYMENT_V2_Service(
                [],
                __DIR__ . '/../../../../../../resources/doit_soa_payment_v2.xml'
            );
            $this->soapClient->__setSoapHeaders(WssSoapHeaderBuilder::buildUsernameToken($username, $password));
        }
    }

    /**
     * {@inheritdoc}
     */
    public function createOrderPayment(OrderPayment $payment)
    {
        /** @var OutputParameters */
        $outputParameters = $this->soapClient->PAYMENT_CREATE(
            OrderPaymentInputParametersMapper::toInputParameters($payment)
        );
        return new OrderPaymentServiceResponse(
            strcasecmp($outputParameters->getP_STATUS(), 'SUCCESS') === 0,
            $outputParameters->getP_RESULT_MESSAGE(),
            Money::USD((int)$outputParameters->getP_CHANGE_BACK() * 100),
            Money::USD((int)$outputParameters->getP_BALANCE_DUE() * 100),
            (new \DateTime($outputParameters->getP_PAID_TO_DATE()))
        );
    }

}
