<?php
namespace edu\wisc\services\cbs\product;

use edu\wisc\services\cbs\common\MoneyConversion;
use edu\wisc\services\cbs\exception\UnsupportedCurrencyException;
use edu\wisc\services\cbs\product\create\generated\InputParameters as CreateInputParamters;
use edu\wisc\services\cbs\product\update\generated\InputParameters as UpdateInputParameters;

/**
 * Maps a {@link Product} to an {@link InputParameters}
 */
class ProductInputParametersMapper
{

    /** @var string flag for 'create' InputParameters */
    static $CREATE = 'create';

    /** @var string flag for 'update' InputParameters */
    static $UPDATE = 'update';

    /**
     * Maps a {@link Product} to an {@link InputParameters} instance
     * @param Product $product
     * @return create\generated\InputParameters|update\generated\InputParameters
     * @throws UnsupportedCurrencyException  when a currency other than USD is used in the Product
     */
    public static function toInputParameters(Product $product, $type)
    {
        $inputParameters = null;
        if ($type === static::$CREATE) {
            $inputParameters = new CreateInputParamters(
                '',
                '',
                '',
                '',
                '',
                '',
                0.0,
                0.0,
                0.0,
                '',
                '',
                '',
                '',
                '',
                0.0,
                '',
                '',
                0.0,
                '',
                '',
                '',
                '',
                ''
            );
        } else if ($type === static::$UPDATE) {
            $inputParameters = new UpdateInputParameters(
                '',
                '',
                '',
                '',
                '',
                '',
                0.0,
                0.0,
                0.0,
                '',
                '',
                '',
                '',
                '',
                0.0,
                '',
                '',
                0.0,
                '',
                '',
                '',
                '',
                ''
            );
        }

        $inputParameters->setP_ITEM_NUMBER($product->getSku())
            ->setP_ITEM_DESCRIPTION($product->getName())
            ->setP_CBS_ITEM_TEMPLATE($product->getCbsItemTemplate())
            ->setP_ITEM_CATEGORY($product->getCategory())
            ->setP_MANUFACTURER_NAME($product->getManufacturer())
            ->setP_MANUFACTURER_PART_NUMBER($product->getManufacturerPartNumber())
            ->setP_COST(MoneyConversion::convertMoneyToFloat($product->getCost()))
            ->setP_MINMAX_LEVEL_MIN($product->getMinQuantity())
            ->setP_MINMAX_LEVEL_MAX($product->getMaxQuantity())
            ->setP_LIFE_CYCLE($product->getLifecycle())
            ->setP_SERIAL_CONTROL_FLAG($product->getSerialControlFlag())
            ->setP_VENDOR($product->getVendor())
            ->setP_SUPPLIER_PART_NUMBER($product->getVendorPartNumber())
            ->setP_UPC($product->getUpc())
            ->setP_BASE_PRICE($product->getBasePrice())
            ->setP_PRICING_TEMPLATE($product->getPricingTemplate())
            ->setP_REFERENCE($product->getReference())
            ->setP_COST_CENTER($product->getCostCenter())
            ->setP_PLANNER_CODE($product->getPlannerCode())
            ->setP_MINMAX_ACTIVE($product->getMinMaxActive())
            ->setP_BUYER($product->getBuyer())
            ->setP_PRODUCT_MANAGER($product->getProductManager())
            ->setP_TEST_MODE($product->getTestMode());

        return $inputParameters;
    }
}
