<?php
namespace edu\wisc\services\cbs\product;

use Money\Money;

/**
 * Unit tests for {@link ProductInputParametersMapper}
 */
class ProductInputParametersMapperTest extends \PHPUnit_Framework_TestCase
{

    /** @test */
    public function mapsProductToInputParameters()
    {
        $product = (new Product())
            ->setSku('itemNumber')
            ->setName('name')
            ->setCategory('category')
            ->setCbsItemTemplate(1389)
            ->setManufacturer('manufacturer')
            ->setManufacturerPartNumber('manufacturerPartNumber')
            ->setCost(Money::USD(99))
            ->setMinQuantity(1)
            ->setMaxQuantity(5)
            ->setLifecycle('lifecycle')
            ->setSerialControlFlag('serialCtrlFlag')
            ->setVendor('vendor')
            ->setVendorPartNumber('vendorPartNumber')
            ->setUpc('upc')
            ->setBasePrice(5.0)
            ->setPricingTemplate('template')
            ->setReference('reference')
            ->setCostCenter('A123456')
            ->setPlannerCode('code')
            ->setMinMaxActive('no')
            ->setBuyer('Bucky Badger')
            ->setProductManager('Bucky Badger')
            ->setTestMode('yesplz');

        $inputParameters = ProductInputParametersMapper::toInputParameters(
            $product,
            ProductInputParametersMapper::$CREATE
        );

        static::assertEquals($product->getSku(), $inputParameters->getP_ITEM_NUMBER());
        static::assertEquals($product->getName(), $inputParameters->getP_ITEM_DESCRIPTION());
        static::assertEquals($product->getCategory(), $inputParameters->getP_ITEM_CATEGORY());
        static::assertEquals($product->getCbsItemTemplate(), $inputParameters->getP_CBS_ITEM_TEMPLATE());
        static::assertEquals($product->getManufacturer(), $inputParameters->getP_MANUFACTURER_NAME());
        static::assertEquals($product->getManufacturerPartNumber(), $inputParameters->getP_MANUFACTURER_PART_NUMBER());
        static::assertTrue(
            $product->getCost()->equals(Money::USD(Money::stringToUnits($inputParameters->getP_COST())))
        );
        static::assertEquals($product->getMinQuantity(), $inputParameters->getP_MINMAX_LEVEL_MIN());
        static::assertEquals($product->getMaxQuantity(), $inputParameters->getP_MINMAX_LEVEL_MAX());
        static::assertEquals($product->getLifecycle(), $inputParameters->getP_LIFE_CYCLE());
        static::assertEquals($product->getSerialControlFlag(), $inputParameters->getP_SERIAL_CONTROL_FLAG());
        static::assertEquals($product->getVendor(), $inputParameters->getP_VENDOR());
        static::assertEquals($product->getVendorPartNumber(), $inputParameters->getP_SUPPLIER_PART_NUMBER());
        static::assertEquals($product->getUpc(), $inputParameters->getP_UPC());
        static::assertEquals($product->getBasePrice(), $inputParameters->getP_BASE_PRICE());
        static::assertEquals($product->getPricingTemplate(), $inputParameters->getP_PRICING_TEMPLATE());
        static::assertEquals($product->getReference(), $inputParameters->getP_REFERENCE());
        static::assertEquals($product->getCostCenter(), $inputParameters->getP_COST_CENTER());
        static::assertEquals($product->getPlannerCode(), $inputParameters->getP_PLANNER_CODE());
        static::assertEquals($product->getMinMaxActive(), $inputParameters->getP_MINMAX_ACTIVE());
        static::assertEquals($product->getBuyer(), $inputParameters->getP_BUYER());
        static::assertEquals($product->getProductManager(), $inputParameters->getP_PRODUCT_MANAGER());
        static::assertEquals($product->getTestMode(), $inputParameters->getP_TEST_MODE());
    }

    /** @test */
    public function handlesNullCost()
    {
        $inputParameters = ProductInputParametersMapper::toInputParameters(
            new Product(),
            ProductInputParametersMapper::$CREATE
        );
        static::assertNull($inputParameters->getP_COST());
    }
}
